@@ -22,6 +22,12 @@ use base qw/Net::Whois::Object/;
 # refer:         [optional]   [single]     [ ]
 # changed:       [mandatory]  [multiple]   [ ]
 # source:        [mandatory]  [single]     [ ]
+__PACKAGE__->attributes( 'primary',   ['domain'] );
+__PACKAGE__->attributes( 'mandatory', [ 'domain', 'descr', 'tech_c', 'admin_c', 'zone_c', 'changed', 'source' ] );
+__PACKAGE__->attributes( 'optional', [ 'org', 'nserver', 'ds_rdata', 'sub_dom', 'dom_net', 'remarks', 'notify', 'mnt_by', 'mnt_lower', 'refer' ] );
+__PACKAGE__->attributes( 'single', [ 'domain', 'refer', 'source' ] );
+__PACKAGE__->attributes( 'multiple', [ 'descr', 'org', 'admin_c', 'tech_c', 'zone_c', 'nserver', 'ds_rdata', 'sub_dom', 'dom_net', 'remarks', 'notify', 'mnt_by', 'mnt_lower', 'changed' ] );
+
 
 =head1 NAME
 
@@ -47,12 +53,6 @@ sub new {
     my $self = bless {}, $class;
     $self->_init(@options);
 
-    $self->attributes( 'primary',   ['domain'] );
-    $self->attributes( 'mandatory', [ 'domain', 'descr', 'tech_c', 'admin_c', 'zone_c', 'changed', 'source' ] );
-    $self->attributes( 'optional', [ 'org', 'nserver', 'ds_rdata', 'sub_dom', 'dom_net', 'remarks', 'notify', 'mnt_by', 'mnt_lower', 'refer' ] );
-    $self->attributes( 'single', [ 'domain', 'refer', 'source' ] );
-    $self->attributes( 'multiple', [ 'descr', 'org', 'admin_c', 'tech_c', 'zone_c', 'nserver', 'ds_rdata', 'sub_dom', 'dom_net', 'remarks', 'notify', 'mnt_by', 'mnt_lower', 'changed' ] );
-
     return $self;
 }
 
@@ -84,14 +84,6 @@ always return the current descr array.
 The name of the organization responsible for the reverse delegation. Or can
 describe the use of the IP range described in the domain object.
 
-=cut
-
-sub descr {
-    my ( $self, $descr ) = @_;
-
-    return $self->_multiple_attribute_setget( 'descr', $descr );
-}
-
 =head2 B<org( [$org] )>
 
 Accessor to the org attribute.
@@ -100,14 +92,6 @@ always return the current org array.
 
 The organisation responsible for this domain.
 
-=cut
-
-sub org {
-    my ( $self, $org ) = @_;
-
-    return $self->_multiple_attribute_setget( 'org', $org );
-}
-
 =head2 B<admin_c( [$contact] )>
 
 Accessor to the admin_c attribute.
@@ -120,14 +104,6 @@ often fulfills a role function, there may be more than one admin_c listed.
 An administrative contact (admin_c) must be someone who is physically
 located at the site of the network.
 
-=cut
-
-sub admin_c {
-    my ( $self, $contact ) = @_;
-
-    return $self->_multiple_attribute_setget( 'admin_c', $contact );
-}
-
 =head2 B<tech_c( [$contact] )>
 
 Accessor to the tech_c attribute.
@@ -142,14 +118,6 @@ A technical contact (tech_c) must be a person responsible for the
 day-to-day operation of the network, but does not need to be
 physically located at the site of the network.
 
-=cut
-
-sub tech_c {
-    my ( $self, $contact ) = @_;
-
-    return $self->_multiple_attribute_setget( 'tech_c', $contact );
-}
-
 =head2 B<zone_c( [$contact] )>
 
 Accessor to the zone_c attribute.
@@ -158,14 +126,6 @@ always return the current zone_c array.
 
 The NIC-handle of a 'person' or 'role' object with authority over a zone.
 
-=cut
-
-sub zone_c {
-    my ( $self, $contact ) = @_;
-
-    return $self->_multiple_attribute_setget( 'zone_c', $contact );
-}
-
 =head2 B<nserver( [$server] )>
 
 Accessor to the nserver attribute.
@@ -175,14 +135,6 @@ always return the current nserver array.
 A list of nameservers for a domain object. A minimum of one nameserver is
 mandatory.
 
-=cut
-
-sub nserver {
-    my ( $self, $server ) = @_;
-
-    return $self->_multiple_attribute_setget( 'nserver', $server );
-}
-
 =head2 B<ds_rdata( [$server] )>
 
 Accessor to the ds_rdata attribute.
@@ -192,14 +144,6 @@ always return the current ds_rdata array.
 The ds_rdata attribute holds information about a signed delegation record
 for DNSSEC (short for DNS Security Extensions)
 
-=cut
-
-sub ds_rdata {
-    my ( $self, $server ) = @_;
-
-    return $self->_multiple_attribute_setget( 'ds_rdata', $server );
-}
-
 =head2 B<sub_dom( [$dom] )>
 
 Accessor to the sub_dom attribute.
@@ -210,14 +154,6 @@ The sub_dom attribute specifies a list of sub-domains of a domain. Domain
 names are relative to the domain represented by the domain object that
 contains this attribute
 
-=cut
-
-sub sub_dom {
-    my ( $self, $dom ) = @_;
-
-    return $self->_multiple_attribute_setget( 'sub_dom', $dom );
-}
-
 =head2 B<dom_net( [$dom_net] )>
 
 Accessor to the dom_net attribute.
@@ -226,14 +162,6 @@ always return the current dom_net array.
 
 The dom_net attribute contains a list of IP networks in a domain.
 
-=cut
-
-sub dom_net {
-    my ( $self, $dom_net ) = @_;
-
-    return $self->_multiple_attribute_setget( 'dom_net', $dom_net );
-}
-
 =head2 B<remarks( [$remark] )>
 
 Accessor to the remarks attribute.
@@ -242,14 +170,6 @@ always return the current remarks array.
 
 General remarks. May include a URL or email address.
 
-=cut
-
-sub remarks {
-    my ( $self, $remark ) = @_;
-
-    return $self->_multiple_attribute_setget( 'remarks', $remark );
-}
-
 =head2 B<notify( [$notify] )>
 
 Accessor to the notify attribute.
@@ -259,14 +179,6 @@ always return the current notify array.
 The email address to which notifications of changes to this object should be
 sent.
 
-=cut
-
-sub notify {
-    my ( $self, $notify ) = @_;
-
-    return $self->_multiple_attribute_setget( 'notify', $notify );
-}
-
 =head2 B<mnt_by( [$mnt_by] )>
 
 Accessor to the mnt_by attribute.
@@ -276,14 +188,6 @@ always return the current mnt_by array.
 Lists a registered 'mntner' used to authorize and authenticate changes to
 this object.
 
-=cut
-
-sub mnt_by {
-    my ( $self, $mnt_by ) = @_;
-
-    return $self->_multiple_attribute_setget( 'mnt_by', $mnt_by );
-}
-
 =head2 B<mnt_lower( [$mnt_lower] )>
 
 Accessor to the mnt_lower attribute.
@@ -294,14 +198,6 @@ The identifier of a registered mntner object used to authorize the creation of
 reverse domain objects more specific than the reverse domain specified by this
 object.
 
-=cut
-
-sub mnt_lower {
-    my ( $self, $mnt_lower ) = @_;
-
-    return $self->_multiple_attribute_setget( 'mnt_lower', $mnt_lower );
-}
-
 =head2 B<refer( [$refer] )>
 
 Accessor to the refer attribute.
@@ -312,14 +208,6 @@ database. See the "RIPE Database Query Reference Manual" for an
 explanation of its use. This will be redundant when forward domains are
 removed and may be deprecated.
 
-=cut
-
-sub refer {
-    my ( $self, $refer ) = @_;
-
-    return $self->_single_attribute_setget( 'refer', $refer );
-}
-
 =head2 B<changed( [$changed] )>
 
 Accessor to the changed attribute.
@@ -335,14 +223,6 @@ Please use the address format specified in RFC 822 - Standard for
 the Format of ARPA Internet Text Message and provide the date
 format using one of the following two formats: YYYYMMDD or YYMMDD.
 
-=cut
-
-sub changed {
-    my ( $self, $changed ) = @_;
-
-    return $self->_multiple_attribute_setget( 'changed', $changed );
-}
-
 =head2 B<source( [$source] )>
 
 Accessor to the source attribute.
@@ -352,10 +232,4 @@ The database where the object is registered.
 
 =cut
 
-sub source {
-    my ( $self, $source ) = @_;
-
-    return $self->_single_attribute_setget( 'source', $source );
-}
-
 1;
