@@ -19,6 +19,11 @@ use base qw/Net::Whois::Object/;
 
 # From http://www.apnic.net/apnic-info/whois_search/using-whois/guide/rtr-set
 # mp-members:    [optional]   [multiple]   [ ]
+__PACKAGE__->attributes( 'primary', ['rtr_set'] );
+__PACKAGE__->attributes( 'mandatory', [ 'rtr_set', 'descr', 'tech_c', 'admin_c', 'mnt_by', 'changed', 'source' ] );
+__PACKAGE__->attributes( 'optional', [ 'members', 'mbrs_by_ref', 'remarks', 'notify', 'mp_members' ] );
+__PACKAGE__->attributes( 'single', [ 'rtr_set', 'source' ] );
+__PACKAGE__->attributes( 'multiple', [ 'descr', 'tech_c', 'admin_c', 'mnt_by', 'changed', 'members', 'mbrs_by_ref', 'remarks', 'notify', 'mp_members' ] );
 
 =head1 NAME
 
@@ -46,12 +51,6 @@ sub new {
     my $self = bless {}, $class;
     $self->_init(@options);
 
-    $self->attributes( 'primary', ['rtr_set'] );
-    $self->attributes( 'mandatory', [ 'rtr_set', 'descr', 'tech_c', 'admin_c', 'mnt_by', 'changed', 'source' ] );
-    $self->attributes( 'optional', [ 'members', 'mbrs_by_ref', 'remarks', 'notify' ] );
-    $self->attributes( 'single', [ 'rtr_set', 'source' ] );
-    $self->attributes( 'multiple', [ 'descr', 'tech_c', 'admin_c', 'mnt_by', 'changed', 'members', 'mbrs_by_ref', 'remarks', 'notify' ] );
-
     return $self;
 }
 
@@ -60,153 +59,65 @@ sub new {
 Accessor to the rtr_set attribute.
 Accepts an optional rtr_set, always return the current rtr_set.
 
-=cut
-
-sub rtr_set {
-    my ( $self, $rtr_set ) = @_;
-
-    return $self->_single_attribute_setget( 'rtr_set', $rtr_set );
-}
-
 =head2 B<descr( [$descr] )>
 
 Accessor to the descr attribute.
 Accepts an optional descr line to be added to the descr array,
 always return the current descr array.
 
-=cut
-
-sub descr {
-    my ( $self, $descr ) = @_;
-
-    return $self->_multiple_attribute_setget( 'descr', $descr );
-}
-
 =head2 B<members( [$member] )>
 
 Accessor to the members attribute.
 Accepts an optional member to be added to the members array,
 always return the current members array.
 
-=cut
-
-sub members {
-    my ( $self, $member ) = @_;
-
-    return $self->_multiple_attribute_setget( 'members', $member );
-}
-
 =head2 B<mbrs_by_ref( [$mbrs_by_ref] )>
 
 Accessor to the mbrs_by_ref attribute.
 Accepts an optional mbrs_by_ref value to be added to the mbrs_by_ref array,
 always return the current mbrs_by_ref array.
 
-=cut
-
-sub mbrs_by_ref {
-    my ( $self, $mbrs_by_ref ) = @_;
-
-    return $self->_multiple_attribute_setget( 'mbrs_by_ref', $mbrs_by_ref );
-}
-
 =head2 B<remarks( [$remark] )>
 
 Accessor to the remarks attribute.
 Accepts an optional remark to be added to the remarks array,
 always return the current remarks array.
 
-=cut
-
-sub remarks {
-    my ( $self, $remark ) = @_;
-
-    return $self->_multiple_attribute_setget( 'remarks', $remark );
-}
-
 =head2 B<tech_c( [$contact] )>
 
 Accessor to the tech_c attribute.
 Accepts an optional contact to be added to the tech_c array,
 always return the current tech_c array.
 
-=cut
-
-sub tech_c {
-    my ( $self, $contact ) = @_;
-
-    return $self->_multiple_attribute_setget( 'tech_c', $contact );
-}
-
 =head2 B<admin_c( [$contact] )>
 
 Accessor to the admin_c attribute.
 Accepts an optional contact to be added to the admin_c array,
 always return the current admin_c array.
 
-=cut
-
-sub admin_c {
-    my ( $self, $contact ) = @_;
-
-    return $self->_multiple_attribute_setget( 'admin_c', $contact );
-}
-
 =head2 B<notify( [$notify] )>
 
 Accessor to the notify attribute.
 Accepts an optional notify value to be added to the notify array,
 always return the current notify array.
 
-=cut
-
-sub notify {
-    my ( $self, $notify ) = @_;
-
-    return $self->_multiple_attribute_setget( 'notify', $notify );
-}
-
 =head2 B<mnt_by( [$mnt_by])>
 
 Accessor to the mnt_by attribute.
 Accepts an optional mnt_by value to be added to the mnt_by array,
 always return the current mnt_by array.
 
-=cut
-
-sub mnt_by {
-    my ( $self, $mnt_by ) = @_;
-
-    return $self->_multiple_attribute_setget( 'mnt_by', $mnt_by );
-}
-
 =head2 B<changed( [$changed] )>
 
 Accessor to the changed attribute.
 Accepts an optional changed value to be added to the changed array,
 always return the current changed array.
 
-=cut
-
-sub changed {
-    my ( $self, $changed ) = @_;
-
-    return $self->_multiple_attribute_setget( 'changed', $changed );
-}
-
 =head2 B<source( [$source] )>
 
 Accessor to the source attribute.
 Accepts an optional source, always return the current source.
 
-=cut
-
-sub source {
-    my ( $self, $source ) = @_;
-
-    return $self->_single_attribute_setget( 'source', $source );
-}
-
 =head2 B<mp_members( [$mp_member] )>
 
 Accessor to the mp_members attribute.
@@ -226,10 +137,4 @@ Explicitly lists IPv4 or IPv6 'members' of the rtr-set can be:
 
 =cut
 
-sub mp_members {
-    my ( $self, $mp_member ) = @_;
-
-    return $self->_multiple_attribute_setget( 'mp_members', $mp_member );
-}
-
 1;
